==> zio-aws-batch_2.13-5.17.122.1-sources.jar: zio/aws/batch/model/CreateJobQueueRequest.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.{TagValue, TagKey, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateJobQueueRequest(
    jobQueueName: String,
    state: Option[zio.aws.batch.model.JQState] = None,
    schedulingPolicyArn: Option[String] = None,
    priority: Integer,
    computeEnvironmentOrder: Iterable[
      zio.aws.batch.model.ComputeEnvironmentOrder
    ],
    tags: Option[Map[TagKey, TagValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.CreateJobQueueRequest = {
    import CreateJobQueueRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
      .builder()
      .jobQueueName(jobQueueName: java.lang.String)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        schedulingPolicyArn.map(value => value: java.lang.String)
      )(_.schedulingPolicyArn)
      .priority(Integer.unwrap(priority): java.lang.Integer)
      .computeEnvironmentOrder(computeEnvironmentOrder.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.CreateJobQueueRequest.ReadOnly =
    zio.aws.batch.model.CreateJobQueueRequest.wrap(buildAwsValue())
}
object CreateJobQueueRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.CreateJobQueueRequest =
      zio.aws.batch.model.CreateJobQueueRequest(
        jobQueueName,
        state.map(value => value),
        schedulingPolicyArn.map(value => value),
        priority,
        computeEnvironmentOrder.map { item =>
          item.asEditable
        },
        tags.map(value => value)
      )
    def jobQueueName: String
    def state: Option[zio.aws.batch.model.JQState]
    def schedulingPolicyArn: Option[String]
    def priority: Integer
    def computeEnvironmentOrder
        : List[zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly]
    def tags: Option[Map[TagKey, TagValue]]
    def getJobQueueName: ZIO[Any, Nothing, String] = ZIO.succeed(jobQueueName)
    def getState: ZIO[Any, AwsError, zio.aws.batch.model.JQState] =
      AwsError.unwrapOptionField("state", state)
    def getSchedulingPolicyArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("schedulingPolicyArn", schedulingPolicyArn)
    def getPriority: ZIO[Any, Nothing, Integer] = ZIO.succeed(priority)
    def getComputeEnvironmentOrder: ZIO[Any, Nothing, List[
      zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly
    ]] = ZIO.succeed(computeEnvironmentOrder)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ) extends zio.aws.batch.model.CreateJobQueueRequest.ReadOnly {
    override val jobQueueName: String = impl.jobQueueName(): String
    override val state: Option[zio.aws.batch.model.JQState] = scala
      .Option(impl.state())
      .map(value => zio.aws.batch.model.JQState.wrap(value))
    override val schedulingPolicyArn: Option[String] =
      scala.Option(impl.schedulingPolicyArn()).map(value => value: String)
    override val priority: Integer =
      zio.aws.batch.model.primitives.Integer(impl.priority())
    override val computeEnvironmentOrder
        : List[zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly] = impl
      .computeEnvironmentOrder()
      .asScala
      .map { item =>
        zio.aws.batch.model.ComputeEnvironmentOrder.wrap(item)
      }
      .toList
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.batch.model.primitives
              .TagKey(key) -> zio.aws.batch.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ): zio.aws.batch.model.CreateJobQueueRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-batch_2.13-5.17.155.1-sources.jar: zio/aws/batch/model/CreateJobQueueRequest.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.{TagValue, TagKey, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateJobQueueRequest(
    jobQueueName: String,
    state: Option[zio.aws.batch.model.JQState] = None,
    schedulingPolicyArn: Option[String] = None,
    priority: Integer,
    computeEnvironmentOrder: Iterable[
      zio.aws.batch.model.ComputeEnvironmentOrder
    ],
    tags: Option[Map[TagKey, TagValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.CreateJobQueueRequest = {
    import CreateJobQueueRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
      .builder()
      .jobQueueName(jobQueueName: java.lang.String)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        schedulingPolicyArn.map(value => value: java.lang.String)
      )(_.schedulingPolicyArn)
      .priority(priority: java.lang.Integer)
      .computeEnvironmentOrder(computeEnvironmentOrder.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.CreateJobQueueRequest.ReadOnly =
    zio.aws.batch.model.CreateJobQueueRequest.wrap(buildAwsValue())
}
object CreateJobQueueRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.CreateJobQueueRequest =
      zio.aws.batch.model.CreateJobQueueRequest(
        jobQueueName,
        state.map(value => value),
        schedulingPolicyArn.map(value => value),
        priority,
        computeEnvironmentOrder.map { item =>
          item.asEditable
        },
        tags.map(value => value)
      )
    def jobQueueName: String
    def state: Option[zio.aws.batch.model.JQState]
    def schedulingPolicyArn: Option[String]
    def priority: Integer
    def computeEnvironmentOrder
        : List[zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly]
    def tags: Option[Map[TagKey, TagValue]]
    def getJobQueueName: ZIO[Any, Nothing, String] = ZIO.succeed(jobQueueName)
    def getState: ZIO[Any, AwsError, zio.aws.batch.model.JQState] =
      AwsError.unwrapOptionField("state", state)
    def getSchedulingPolicyArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("schedulingPolicyArn", schedulingPolicyArn)
    def getPriority: ZIO[Any, Nothing, Integer] = ZIO.succeed(priority)
    def getComputeEnvironmentOrder: ZIO[Any, Nothing, List[
      zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly
    ]] = ZIO.succeed(computeEnvironmentOrder)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ) extends zio.aws.batch.model.CreateJobQueueRequest.ReadOnly {
    override val jobQueueName: String = impl.jobQueueName(): String
    override val state: Option[zio.aws.batch.model.JQState] = scala
      .Option(impl.state())
      .map(value => zio.aws.batch.model.JQState.wrap(value))
    override val schedulingPolicyArn: Option[String] =
      scala.Option(impl.schedulingPolicyArn()).map(value => value: String)
    override val priority: Integer = impl.priority(): Integer
    override val computeEnvironmentOrder
        : List[zio.aws.batch.model.ComputeEnvironmentOrder.ReadOnly] = impl
      .computeEnvironmentOrder()
      .asScala
      .map { item =>
        zio.aws.batch.model.ComputeEnvironmentOrder.wrap(item)
      }
      .toList
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.batch.model.primitives
              .TagKey(key) -> zio.aws.batch.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.CreateJobQueueRequest
  ): zio.aws.batch.model.CreateJobQueueRequest.ReadOnly = new Wrapper(impl)
}
